/*
 * JavaPT09 - Stripes
 * Copyright (c) 2009 Present Technologies
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.example.javapt09.stripes.action;

import net.sourceforge.stripes.action.DefaultHandler;
import net.sourceforge.stripes.action.DontValidate;
import net.sourceforge.stripes.action.ForwardResolution;
import net.sourceforge.stripes.action.LocalizableMessage;
import net.sourceforge.stripes.action.RedirectResolution;
import net.sourceforge.stripes.action.Resolution;
import net.sourceforge.stripes.validation.SimpleError;
import net.sourceforge.stripes.validation.Validate;
import net.sourceforge.stripes.validation.ValidateNestedProperties;
import net.sourceforge.stripes.validation.ValidationErrors;
import net.sourceforge.stripes.validation.ValidationMethod;

import com.example.javapt09.stripes.entity.User;

/**
 * Smart binding action bean.
 */
public class SmartBindingActionBean extends BaseActionBean {

    @ValidateNestedProperties({
        @Validate(field = "firstName", required = true, maxlength = 100),
        @Validate(field = "lastName", required = true, maxlength = 100)
    })
    private User user;

    public User getUser() {
        return user;
    }

    public void setUser(User user) {
        this.user = user;
    }

    @DefaultHandler
    @DontValidate
    public Resolution main() {
        return new ForwardResolution("/WEB-INF/jsp/binding-validation.jsp");
    }

    public Resolution print() {
        getContext().getMessages().add(new LocalizableMessage("print.success", user));
        return new RedirectResolution(SmartBindingActionBean.class);
    }

    @ValidationMethod
    public void validate(ValidationErrors errors) {
        if (user.getLastName().equals(user.getFirstName())) {
            errors.add("lastName", new SimpleError("First and last name must be different!"));
        }
    }
}
